validate_refs

Function validate_refs 

pub fn validate_refs(
    template: &str,
    declared_aliases: &FxHashSet<String>,
    task_id: &str,
) -> Result<(), NikaError>
Validate that all template references exist in declared aliases (static validation)

This is called by nika validate before runtime. Returns Ok(()) if valid, Err with first unknown alias if not.