ModelStorage

Trait ModelStorage 

pub trait ModelStorage {
    // Required methods
    async fn download<F>(
        &self,
        request: &DownloadRequest<'_>,
        progress: F,
    ) -> Result<DownloadResult>
       where F: Fn(PullProgress) + Send + 'static;
    fn list_models(&self) -> Result<Vec<ModelInfo>, BackendError>;
    fn exists(&self, model_id: &str) -> bool;
    fn model_info(&self, model_id: &str) -> Result<ModelInfo, BackendError>;
    fn delete(&self, model_id: &str) -> Result<(), BackendError>;
    fn model_path(&self, model_id: &str) -> Result<PathBuf, BackendError>;
}
Trait for model storage backends.

Provides a common interface for downloading and managing local models.

Required Methods

async fn download<F>( &self, request: &DownloadRequest<'_>, progress: F, ) -> Result<DownloadResult>
where F: Fn(PullProgress) + Send + 'static,

Download a model with progress callback.

fn list_models(&self) -> Result<Vec<ModelInfo>, BackendError>

List all downloaded models.

fn exists(&self, model_id: &str) -> bool

Check if a model exists locally.

fn model_info(&self, model_id: &str) -> Result<ModelInfo, BackendError>

Get info about a local model.

fn delete(&self, model_id: &str) -> Result<(), BackendError>

Delete a local model.

fn model_path(&self, model_id: &str) -> Result<PathBuf, BackendError>

Get the path to a model file.

Security

Validates that model_id doesn’t escape storage directory via path traversal.

Errors

Returns BackendError::PathTraversal if the path would escape the storage directory.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors