Source span tracking โ re-exported from nika-core.
Structs
- Byte
Offset - A byte offset in a source file.
- FileId
- Unique identifier for a source file in the SourceRegistry.
- Source
File - A single source file with its content and path.
- Source
Registry - Registry of all source files in a compilation unit.
- Source
Snippet - A snippet of source code for error display.
- Span
- A span in a source file (byte range + file ID).
- Spanned
- A value with an associated span.