pub fn validate_refs(
template: &str,
declared_aliases: &FxHashSet<String>,
task_id: &str,
) -> Result<(), NikaError>Expand description
Validate that all template references exist in declared aliases (static validation)
This is called by nika validate before runtime.
Returns Ok(()) if valid, Err with first unknown alias if not.