Module source

Module source 

Source span tracking โ€” re-exported from nika-core.

Structs

ByteOffset
A byte offset in a source file.
FileId
Unique identifier for a source file in the SourceRegistry.
SourceFile
A single source file with its content and path.
SourceRegistry
Registry of all source files in a compilation unit.
SourceSnippet
A snippet of source code for error display.
Span
A span in a source file (byte range + file ID).
Spanned
A value with an associated span.